{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "bleachsims",
            "doc": "filter similarity file by E-value and number of hits\n>bleachsims -s <input> -o <output> -m 20 -r 0 -c 3\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "bleachsims.log",
            "stderr": "bleachsims.error",
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Remove all evalues with an exponent lower than cutoff, default 3",
                    "default": 3,
                    "inputBinding": {
                        "prefix": "-c"
                    },
                    "id": "#bleachsims.tool.cwl/cutoff"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "only apply cutoff filter",
                    "inputBinding": {
                        "prefix": "--eval_only"
                    },
                    "id": "#bleachsims.tool.cwl/cutoffOnly"
                },
                {
                    "type": "File",
                    "doc": "Input similarity blast-m8 file",
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#bleachsims.tool.cwl/input"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Minimum number of hits per query, default 20",
                    "default": 20,
                    "inputBinding": {
                        "prefix": "-m"
                    },
                    "id": "#bleachsims.tool.cwl/min"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "only apply cutoff filter",
                    "inputBinding": {
                        "prefix": "--min_hit_only"
                    },
                    "id": "#bleachsims.tool.cwl/minHitOnly"
                },
                {
                    "type": "string",
                    "doc": "Output name",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#bleachsims.tool.cwl/outName"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Best evalue plus this exponent that will be returned, default 0 (no range)",
                    "default": 0,
                    "inputBinding": {
                        "prefix": "-r"
                    },
                    "id": "#bleachsims.tool.cwl/range"
                }
            ],
            "baseCommand": [
                "bleachsims"
            ],
            "id": "#bleachsims.tool.cwl",
            "outputs": [
                {
                    "type": "File",
                    "id": "#bleachsims.tool.cwl/error",
                    "outputBinding": {
                        "glob": "bleachsims.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#bleachsims.tool.cwl/info",
                    "outputBinding": {
                        "glob": "bleachsims.log"
                    }
                },
                {
                    "type": "File",
                    "doc": "Output filtered similarity blast-m8 file",
                    "outputBinding": {
                        "glob": "$(inputs.outName)"
                    },
                    "id": "#bleachsims.tool.cwl/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "GNU cat",
            "doc": "Concatenate FILE(s) to standard output",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "$(inputs.outName)",
            "stderr": "cat.error",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "doc": "List of files to concatenate",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#cat.tool.cwl/files"
                },
                {
                    "type": "string",
                    "id": "#cat.tool.cwl/outName"
                }
            ],
            "baseCommand": [
                "cat"
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#cat.tool.cwl/error",
                    "outputBinding": {
                        "glob": "cat.error"
                    }
                },
                {
                    "type": "File",
                    "doc": "Concatenated file",
                    "outputBinding": {
                        "glob": "$(inputs.outName)"
                    },
                    "id": "#cat.tool.cwl/output"
                }
            ],
            "id": "#cat.tool.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "CD-HIT",
            "doc": "cluster protein sequences\nuse max available cpus and memory\n>cdhit -n 5 -d 0 -T 0 -M 0 -c 0.9 -i <input> -o <output>\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "cdhit.log",
            "stderr": "cdhit.error",
            "inputs": [
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "doc": "Percent identity threshold, default 0.9",
                    "default": 0.9,
                    "inputBinding": {
                        "prefix": "-c"
                    },
                    "id": "#cdhit.tool.cwl/identity"
                },
                {
                    "type": "File",
                    "doc": "Input fasta format file",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#cdhit.tool.cwl/input"
                },
                {
                    "type": "string",
                    "doc": "Output name",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#cdhit.tool.cwl/outName"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Word length, default 5",
                    "default": 5,
                    "inputBinding": {
                        "prefix": "-n"
                    },
                    "id": "#cdhit.tool.cwl/word"
                }
            ],
            "baseCommand": [
                "cdhit"
            ],
            "arguments": [
                {
                    "prefix": "-M",
                    "valueFrom": "0"
                },
                {
                    "prefix": "-T",
                    "valueFrom": "0"
                },
                {
                    "prefix": "-d",
                    "valueFrom": "0"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#cdhit.tool.cwl/error",
                    "outputBinding": {
                        "glob": "cdhit.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#cdhit.tool.cwl/info",
                    "outputBinding": {
                        "glob": "cdhit.log"
                    }
                },
                {
                    "type": "File",
                    "doc": "Output cluster mapping file",
                    "outputBinding": {
                        "glob": "$(inputs.outName).clstr"
                    },
                    "id": "#cdhit.tool.cwl/outClstr"
                },
                {
                    "type": "File",
                    "doc": "Output fasta format file",
                    "outputBinding": {
                        "glob": "$(inputs.outName)"
                    },
                    "id": "#cdhit.tool.cwl/outSeq"
                }
            ],
            "id": "#cdhit.tool.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "filter features",
            "doc": "remove predicted genes that have overlap with identified rRNAs\n>filter_feature.pl --seq <sequences> --sim <similarity> --clust <cluster> --output <output> --overlap <overlap> --memory <memory in MB> --tmp_dir <temp directory>\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "listing": [
                        "$(inputs.sequences)",
                        "$(inputs.similarity)",
                        "$(inputs.cluster)"
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "filter_feature.log",
            "stderr": "filter_feature.error",
            "inputs": [
                {
                    "type": "File",
                    "doc": "Input RNA cluster mapping file",
                    "inputBinding": {
                        "prefix": "--clust"
                    },
                    "id": "#filter_feature.tool.cwl/cluster"
                },
                {
                    "type": "string",
                    "doc": "Output filtered protein fasta",
                    "inputBinding": {
                        "prefix": "--output"
                    },
                    "id": "#filter_feature.tool.cwl/outName"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Overlap threshold in bp to accept, default 10",
                    "default": 10,
                    "inputBinding": {
                        "prefix": "--overlap"
                    },
                    "id": "#filter_feature.tool.cwl/overlap"
                },
                {
                    "type": "File",
                    "doc": "Input tabbed protein sequence file",
                    "inputBinding": {
                        "prefix": "--seq"
                    },
                    "id": "#filter_feature.tool.cwl/sequences"
                },
                {
                    "type": "File",
                    "doc": "Input RNA similarity file",
                    "inputBinding": {
                        "prefix": "--sim"
                    },
                    "id": "#filter_feature.tool.cwl/similarity"
                }
            ],
            "baseCommand": [
                "filter_feature.pl"
            ],
            "arguments": [
                {
                    "prefix": "--memory",
                    "valueFrom": "$(runtime.ram)"
                },
                {
                    "prefix": "--tmpdir",
                    "valueFrom": "$(runtime.tmpdir)"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#filter_feature.tool.cwl/error",
                    "outputBinding": {
                        "glob": "filter_feature.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#filter_feature.tool.cwl/info",
                    "outputBinding": {
                        "glob": "filter_feature.log"
                    }
                },
                {
                    "type": "File",
                    "doc": "Output filtered protein fasta file",
                    "outputBinding": {
                        "glob": "$(inputs.outName)"
                    },
                    "id": "#filter_feature.tool.cwl/output"
                }
            ],
            "id": "#filter_feature.tool.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "cluster file reformat",
            "doc": "re-formats cd-hit .clstr file into mg-rast .mapping file\n>format_cluster.pl --input <input> --output <output>\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "format_cluster.log",
            "stderr": "format_cluster.error",
            "inputs": [
                {
                    "type": "File",
                    "doc": "Input .clstr format file",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#format_cluster.tool.cwl/input"
                },
                {
                    "type": "string",
                    "doc": "Output .mapping format file",
                    "inputBinding": {
                        "prefix": "--output"
                    },
                    "id": "#format_cluster.tool.cwl/outName"
                }
            ],
            "baseCommand": [
                "format_cluster.pl"
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#format_cluster.tool.cwl/error",
                    "outputBinding": {
                        "glob": "format_cluster.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#format_cluster.tool.cwl/info",
                    "outputBinding": {
                        "glob": "format_cluster.log"
                    }
                },
                {
                    "type": "File",
                    "doc": "Output .mapping format file",
                    "outputBinding": {
                        "glob": "$(inputs.outName)"
                    },
                    "id": "#format_cluster.tool.cwl/output"
                }
            ],
            "id": "#format_cluster.tool.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "FragGeneScan",
            "doc": "hidden Markov model for predicting prokaryotic coding regions\n>run_FragGeneScan.pl --genome <input> --out <output> --complete 0 --train 454_30\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "run_FragGeneScan.log",
            "stderr": "run_FragGeneScan.error",
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "1 if the sequence file has complete genomic sequences\n0 if the sequence file has short sequence reads\ndefault is 0\n",
                    "default": 0,
                    "inputBinding": {
                        "prefix": "--complete"
                    },
                    "id": "#fraggenescan.tool.cwl/complete"
                },
                {
                    "type": "File",
                    "doc": "Input fasta format file",
                    "inputBinding": {
                        "prefix": "--genome"
                    },
                    "id": "#fraggenescan.tool.cwl/input"
                },
                {
                    "type": "string",
                    "doc": "Output name",
                    "inputBinding": {
                        "prefix": "--out"
                    },
                    "id": "#fraggenescan.tool.cwl/outName"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Training model to use, default is 454_30",
                    "default": "454_30",
                    "inputBinding": {
                        "prefix": "--train"
                    },
                    "id": "#fraggenescan.tool.cwl/train"
                }
            ],
            "baseCommand": [
                "run_FragGeneScan.pl"
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#fraggenescan.tool.cwl/error",
                    "outputBinding": {
                        "glob": "run_FragGeneScan.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#fraggenescan.tool.cwl/info",
                    "outputBinding": {
                        "glob": "run_FragGeneScan.log"
                    }
                },
                {
                    "type": "File",
                    "doc": "Output .ffn (dna) file",
                    "outputBinding": {
                        "glob": "$(inputs.outName).ffn"
                    },
                    "id": "#fraggenescan.tool.cwl/outDNA"
                },
                {
                    "type": "File",
                    "doc": "Output .faa (protein) file",
                    "outputBinding": {
                        "glob": "$(inputs.outName).faa"
                    },
                    "id": "#fraggenescan.tool.cwl/outProt"
                }
            ],
            "id": "#fraggenescan.tool.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "seqUtil",
            "doc": "Utility tool for various sequence file transformations.\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "seqUtil.log",
            "stderr": "seqUtil.error",
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Return fasta with each sequence truncated to 1024 bps",
                    "inputBinding": {
                        "prefix": "--bowtie_truncate"
                    },
                    "id": "#seqUtil.tool.cwl/bowtieTruncate"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Transform fasta to tabbed",
                    "inputBinding": {
                        "prefix": "--fasta2tab"
                    },
                    "id": "#seqUtil.tool.cwl/fasta2tab"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Transform fastq to fasta",
                    "inputBinding": {
                        "prefix": "--fastq2fasta"
                    },
                    "id": "#seqUtil.tool.cwl/fastq2fasta"
                },
                {
                    "type": "string",
                    "doc": "Output sequence file",
                    "inputBinding": {
                        "prefix": "--output"
                    },
                    "id": "#seqUtil.tool.cwl/output"
                },
                {
                    "type": "File",
                    "doc": "Input sequence file",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#seqUtil.tool.cwl/sequences"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Sort fasta file by ID",
                    "inputBinding": {
                        "prefix": "--sortbyid"
                    },
                    "id": "#seqUtil.tool.cwl/sortbyid"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Transform fasta to ID list, sorted by ID",
                    "inputBinding": {
                        "prefix": "--sortbyid2id"
                    },
                    "id": "#seqUtil.tool.cwl/sortbyid2id"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Transform fasta to tabbed, sorted by ID",
                    "inputBinding": {
                        "prefix": "--sortbyid2tab"
                    },
                    "id": "#seqUtil.tool.cwl/sortbyid2tab"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "List of sequences to subset input by, required with subsetSeqs option",
                    "inputBinding": {
                        "prefix": "--list"
                    },
                    "id": "#seqUtil.tool.cwl/subsetList"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Return fasta with each sequence truncated to 1024 bps",
                    "inputBinding": {
                        "prefix": "--subset_seqs"
                    },
                    "id": "#seqUtil.tool.cwl/subsetSeqs"
                }
            ],
            "baseCommand": [
                "seqUtil"
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#seqUtil.tool.cwl/error",
                    "outputBinding": {
                        "glob": "seqUtil.error"
                    }
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    },
                    "id": "#seqUtil.tool.cwl/file"
                },
                {
                    "type": "File",
                    "id": "#seqUtil.tool.cwl/info",
                    "outputBinding": {
                        "glob": "seqUtil.log"
                    }
                }
            ],
            "id": "#seqUtil.tool.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "annotate sims",
            "doc": "create expanded annotated sims files from input md5 sim file and m5nr db\nsims_annotate.pl --verbose --in_sim <input> --in_scg <scgs> --ann_file <database> --format <seqFormat> --out_filter <outFilter> --out_expand <outExpand> -out_lca <outLca> --frag_num 5000\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "sims_annotate.log",
            "stderr": "sims_annotate.error",
            "inputs": [
                {
                    "type": "File",
                    "doc": "BerkelyDB of condensed M5NR",
                    "inputBinding": {
                        "prefix": "--ann_file"
                    },
                    "id": "#sims_annotate.tool.cwl/database"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Number of fragment chunks to load in memory at once before processing, default 5000",
                    "default": 5000,
                    "inputBinding": {
                        "prefix": "--frag_num"
                    },
                    "id": "#sims_annotate.tool.cwl/fragNum"
                },
                {
                    "type": "File",
                    "doc": "Input similarity blast-m8 file",
                    "inputBinding": {
                        "prefix": "--in_sim"
                    },
                    "id": "#sims_annotate.tool.cwl/input"
                },
                {
                    "type": "string",
                    "doc": "Output expanded protein sim file (protein mode only)",
                    "inputBinding": {
                        "prefix": "--out_expand"
                    },
                    "id": "#sims_annotate.tool.cwl/outExpandName"
                },
                {
                    "type": "string",
                    "doc": "Output filtered sim file",
                    "inputBinding": {
                        "prefix": "--out_filter"
                    },
                    "id": "#sims_annotate.tool.cwl/outFilterName"
                },
                {
                    "type": "string",
                    "doc": "Output expanded LCA file (protein and rna mode)",
                    "inputBinding": {
                        "prefix": "--out_lca"
                    },
                    "id": "#sims_annotate.tool.cwl/outLcaName"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "md5 single copy gene file",
                    "inputBinding": {
                        "prefix": "--in_scg"
                    },
                    "id": "#sims_annotate.tool.cwl/scgs"
                },
                {
                    "type": "string",
                    "doc": "Type of sequences data in input file, rna or protein",
                    "default": "protein",
                    "inputBinding": {
                        "prefix": "--format"
                    },
                    "id": "#sims_annotate.tool.cwl/seqFormat"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Verbose logging mode",
                    "inputBinding": {
                        "prefix": "--verbose"
                    },
                    "id": "#sims_annotate.tool.cwl/verbose"
                }
            ],
            "baseCommand": [
                "sims_annotate.pl"
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#sims_annotate.tool.cwl/error",
                    "outputBinding": {
                        "glob": "sims_annotate.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#sims_annotate.tool.cwl/info",
                    "outputBinding": {
                        "glob": "sims_annotate.log"
                    }
                },
                {
                    "type": "File",
                    "doc": "Output expanded sim file",
                    "outputBinding": {
                        "glob": "$(inputs.outExpandName)"
                    },
                    "id": "#sims_annotate.tool.cwl/outExpand"
                },
                {
                    "type": "File",
                    "doc": "Output filtered similarity file",
                    "outputBinding": {
                        "glob": "$(inputs.outFilterName)"
                    },
                    "id": "#sims_annotate.tool.cwl/outFilter"
                },
                {
                    "type": "File",
                    "doc": "Output expanded LCA file",
                    "outputBinding": {
                        "glob": "$(inputs.outLcaName)"
                    },
                    "id": "#sims_annotate.tool.cwl/outLca"
                }
            ],
            "id": "#sims_annotate.tool.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "GNU sort",
            "doc": "sort text file base on given field(s)",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "sort.log",
            "stderr": "sort.error",
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "use SEP instead of non-blank to blank transition, default is tab",
                    "inputBinding": {
                        "prefix": "-t",
                        "valueFrom": "$(\"\\u0009\")"
                    },
                    "id": "#sort.tool.cwl/field"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "doc": "Files to sort",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#sort.tool.cwl/input"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-k"
                        }
                    },
                    "doc": "start a key at POS1, end it at POS2 (origin 1)",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#sort.tool.cwl/key"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "merge only, the input files are assumed to be pre-sorted",
                    "inputBinding": {
                        "prefix": "-m"
                    },
                    "id": "#sort.tool.cwl/merge"
                },
                {
                    "type": "string",
                    "doc": "write result to FILE instead of standard output",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#sort.tool.cwl/outName"
                }
            ],
            "baseCommand": [
                "sort"
            ],
            "arguments": [
                {
                    "prefix": "-T",
                    "valueFrom": "$(runtime.tmpdir)"
                },
                {
                    "prefix": "-S",
                    "valueFrom": "$(runtime.ram)M"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#sort.tool.cwl/error",
                    "outputBinding": {
                        "glob": "sort.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#sort.tool.cwl/info",
                    "outputBinding": {
                        "glob": "sort.log"
                    }
                },
                {
                    "type": "File",
                    "doc": "The sorted file",
                    "outputBinding": {
                        "glob": "$(inputs.outName)"
                    },
                    "id": "#sort.tool.cwl/output"
                }
            ],
            "id": "#sort.tool.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "superBLAT",
            "doc": "multi-threaded fast sequence search command line tool, protein only\n>superblat -fastMap -prot -out blast8 <database> <query> <output>\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "superblat.log",
            "stderr": "superblat.error",
            "inputs": [
                {
                    "type": "File",
                    "doc": "Database fasta format file",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#superblat.tool.cwl/database"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Run for fast DNA/DNA remapping - not allowing introns",
                    "inputBinding": {
                        "prefix": "-fastMap"
                    },
                    "id": "#superblat.tool.cwl/fastMap"
                },
                {
                    "type": "string",
                    "doc": "Output name",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#superblat.tool.cwl/outName"
                },
                {
                    "type": "File",
                    "doc": "Query fasta format file",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#superblat.tool.cwl/query"
                }
            ],
            "baseCommand": [
                "superblat"
            ],
            "arguments": [
                "-prot",
                "-out=blast8"
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#superblat.tool.cwl/error",
                    "outputBinding": {
                        "glob": "superblat.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#superblat.tool.cwl/info",
                    "outputBinding": {
                        "glob": "superblat.log"
                    }
                },
                {
                    "type": "File",
                    "doc": "Output tab separated similarity file",
                    "outputBinding": {
                        "glob": "$(inputs.outName)"
                    },
                    "id": "#superblat.tool.cwl/output"
                }
            ],
            "id": "#superblat.tool.cwl"
        },
        {
            "class": "Workflow",
            "label": "protein annotation",
            "doc": "Proteins - predict, filter, cluster, identify, annotate",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#main/jobid"
                },
                {
                    "type": "File",
                    "id": "#main/m5nrBDB"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/m5nrFull"
                },
                {
                    "type": "File",
                    "id": "#main/m5nrSCG"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.9,
                    "id": "#main/protIdentity"
                },
                {
                    "type": "File",
                    "id": "#main/rnaClustMap"
                },
                {
                    "type": "File",
                    "id": "#main/rnaSims"
                },
                {
                    "type": "File",
                    "id": "#main/sequences"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/formatCluster/output",
                    "id": "#main/protClustMapOut"
                },
                {
                    "type": "File",
                    "outputSource": "#main/protCluster/outSeq",
                    "id": "#main/protClustSeqOut"
                },
                {
                    "type": "File",
                    "outputSource": "#main/annotateSims/outExpand",
                    "id": "#main/protExpandOut"
                },
                {
                    "type": "File",
                    "outputSource": "#main/protFeature/outProt",
                    "id": "#main/protFeatureOut"
                },
                {
                    "type": "File",
                    "outputSource": "#main/protFilter/output",
                    "id": "#main/protFilterFeatureOut"
                },
                {
                    "type": "File",
                    "outputSource": "#main/annotateSims/outFilter",
                    "id": "#main/protFilterOut"
                },
                {
                    "type": "File",
                    "outputSource": "#main/annotateSims/outLca",
                    "id": "#main/protLCAOut"
                },
                {
                    "type": "File",
                    "outputSource": "#main/bleachSims/output",
                    "id": "#main/protSimsOut"
                }
            ],
            "steps": [
                {
                    "run": "#sims_annotate.tool.cwl",
                    "in": [
                        {
                            "source": "#main/m5nrBDB",
                            "id": "#main/annotateSims/database"
                        },
                        {
                            "source": "#main/bleachSims/output",
                            "id": "#main/annotateSims/input"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).650.aa.expand.protein",
                            "id": "#main/annotateSims/outExpandName"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).650.aa.sims.filter",
                            "id": "#main/annotateSims/outFilterName"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).650.aa.expand.lca",
                            "id": "#main/annotateSims/outLcaName"
                        },
                        {
                            "source": "#main/m5nrSCG",
                            "id": "#main/annotateSims/scgs"
                        },
                        {
                            "valueFrom": "protein",
                            "id": "#main/annotateSims/seqFormat"
                        }
                    ],
                    "out": [
                        "#main/annotateSims/outFilter",
                        "#main/annotateSims/outExpand",
                        "#main/annotateSims/outLca"
                    ],
                    "id": "#main/annotateSims"
                },
                {
                    "run": "#bleachsims.tool.cwl",
                    "in": [
                        {
                            "source": "#main/sortSims/output",
                            "id": "#main/bleachSims/input"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).650.superblat.sims",
                            "id": "#main/bleachSims/outName"
                        }
                    ],
                    "out": [
                        "#main/bleachSims/output"
                    ],
                    "id": "#main/bleachSims"
                },
                {
                    "run": "#cat.tool.cwl",
                    "in": [
                        {
                            "source": "#main/superblat/output",
                            "id": "#main/catSims/files"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).superblat.sims.raw",
                            "id": "#main/catSims/outName"
                        }
                    ],
                    "out": [
                        "#main/catSims/output"
                    ],
                    "id": "#main/catSims"
                },
                {
                    "run": "#format_cluster.tool.cwl",
                    "in": [
                        {
                            "source": "#main/protCluster/outClstr",
                            "id": "#main/formatCluster/input"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).550.cluster.aa90.mapping",
                            "id": "#main/formatCluster/outName"
                        }
                    ],
                    "out": [
                        "#main/formatCluster/output"
                    ],
                    "id": "#main/formatCluster"
                },
                {
                    "run": "#cdhit.tool.cwl",
                    "in": [
                        {
                            "source": "#main/protIdentity",
                            "id": "#main/protCluster/identity"
                        },
                        {
                            "source": "#main/protFilter/output",
                            "id": "#main/protCluster/input"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).550.cluster.aa90.faa",
                            "id": "#main/protCluster/outName"
                        }
                    ],
                    "out": [
                        "#main/protCluster/outSeq",
                        "#main/protCluster/outClstr"
                    ],
                    "id": "#main/protCluster"
                },
                {
                    "run": "#fraggenescan.tool.cwl",
                    "in": [
                        {
                            "source": "#main/sequences",
                            "id": "#main/protFeature/input"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).350.genecalling.coding",
                            "id": "#main/protFeature/outName"
                        }
                    ],
                    "out": [
                        "#main/protFeature/outProt"
                    ],
                    "id": "#main/protFeature"
                },
                {
                    "run": "#filter_feature.tool.cwl",
                    "in": [
                        {
                            "source": "#main/rnaClustMap",
                            "id": "#main/protFilter/cluster"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).375.filtering.faa",
                            "id": "#main/protFilter/outName"
                        },
                        {
                            "source": "#main/sortProt/file",
                            "id": "#main/protFilter/sequences"
                        },
                        {
                            "source": "#main/rnaSims",
                            "id": "#main/protFilter/similarity"
                        }
                    ],
                    "out": [
                        "#main/protFilter/output"
                    ],
                    "id": "#main/protFilter"
                },
                {
                    "run": "#seqUtil.tool.cwl",
                    "in": [
                        {
                            "source": "#main/protFeature/outProt",
                            "valueFrom": "$(self.basename).sort.tab",
                            "id": "#main/sortProt/output"
                        },
                        {
                            "source": "#main/protFeature/outProt",
                            "id": "#main/sortProt/sequences"
                        },
                        {
                            "default": true,
                            "id": "#main/sortProt/sortbyid2tab"
                        }
                    ],
                    "out": [
                        "#main/sortProt/file"
                    ],
                    "id": "#main/sortProt"
                },
                {
                    "run": "#sort.tool.cwl",
                    "in": [
                        {
                            "source": "#main/catSims/output",
                            "valueFrom": "$([self])",
                            "id": "#main/sortSims/input"
                        },
                        {
                            "valueFrom": "$([\"1,1\"])",
                            "id": "#main/sortSims/key"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).superblat.sims.sort",
                            "id": "#main/sortSims/outName"
                        }
                    ],
                    "out": [
                        "#main/sortSims/output"
                    ],
                    "id": "#main/sortSims"
                },
                {
                    "run": "#superblat.tool.cwl",
                    "scatter": [
                        "#main/superblat/database",
                        "#main/superblat/outName"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/m5nrFull",
                            "id": "#main/superblat/database"
                        },
                        {
                            "default": true,
                            "id": "#main/superblat/fastMap"
                        },
                        {
                            "source": "#main/m5nrFull",
                            "valueFrom": "$(self.basename).superblat.sims",
                            "id": "#main/superblat/outName"
                        },
                        {
                            "source": "#main/protCluster/outSeq",
                            "id": "#main/superblat/query"
                        }
                    ],
                    "out": [
                        "#main/superblat/output"
                    ],
                    "id": "#main/superblat"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
